@@ -12,29 +12,25 @@ import scipy.sparse
 
 def remove_self_loop_edge(edge_index, edge_weight=None):
     edge_index_is_tensor = tf.is_tensor(edge_index)
-    edge_weight_is_tensor = edge_weight is not None and tf.is_tensor(edge_weight)
+    edge_weight_is_tensor = tf.is_tensor(edge_weight)
 
-    if edge_index_is_tensor:
+    row, col = edge_index[0], edge_index[1]
+    mask = tf.not_equal(row, col)
+
+    edge_index = tf.boolean_mask(edge_index, mask, axis=1)
+    if edge_weight is not None:
+        edge_weight = tf.boolean_mask(edge_weight, mask, axis=0)
+
+    if not edge_index_is_tensor:
         edge_index = edge_index.numpy()
 
-    if edge_weight_is_tensor:
+    if edge_weight is not None and not edge_weight_is_tensor:
         edge_weight = edge_weight.numpy()
 
-    row, col = edge_index
-    mask = row != col
-    edge_index = edge_index[:, mask]
-    if edge_weight is not None:
-        edge_weight = edge_weight[mask]
-
-    if edge_index_is_tensor:
-        edge_index = tf.convert_to_tensor(edge_index)
-
-    if edge_weight_is_tensor:
-        edge_weight = tf.convert_to_tensor(edge_weight)
-
     return edge_index, edge_weight
 
 
+
 def convert_edge_to_nx_graph(edge_index, edge_properties=[], convert_to_directed=False):
     edge_index = convert_union_to_numpy(edge_index, dtype=np.int32)
     edge_properties = [convert_union_to_numpy(edge_property) for edge_property in edge_properties]
@@ -323,7 +319,7 @@ def get_laplacian(edge_index, edge_weight, normalization_type, num_nodes, fill_w
     if normalization_type is not None:
         assert normalization_type in [None,'sym', 'rw']
 
-    row, col = edge_index
+    row, col = edge_index[0], edge_index[1]
     deg = tf.math.unsorted_segment_sum(edge_weight, row, num_segments=num_nodes)
     ##L = D - A
     if normalization_type is None:
